# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You
# may not use this file except in compliance with the License. A copy of
# the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is
# distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
# ANY KIND, either express or implied. See the License for the specific
# language governing permissions and limitations under the License.

from ebcli.lib import elasticbeanstalk
from ebcli.core import io


def get_abortable_envs(app_name):
    envs = elasticbeanstalk.get_app_environments(app_name)
    return [e for e in envs if e.is_abortable]


def abort_operation(env_name):
    elasticbeanstalk.abort_environment_update(env_name)
    io.echo('Aborting update to environment "{}". \n'
            'Type "eb events -f" to watch the environment events.'.format(env_name))
